==> kubernetes-model-flowcontrol-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/PriorityLevelConfigurationListFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PriorityLevelConfigurationListFluent<A extends PriorityLevelConfigurationListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,PriorityLevelConfiguration item);
  public A setToItems(Integer index,PriorityLevelConfiguration item);
  public A addToItems(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.PriorityLevelConfiguration... items);
  public A addAllToItems(Collection<PriorityLevelConfiguration> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.PriorityLevelConfiguration... items);
  public A removeAllFromItems(Collection<PriorityLevelConfiguration> items);
  public A removeMatchingFromItems(Predicate<PriorityLevelConfigurationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PriorityLevelConfiguration> getItems();
  public List<PriorityLevelConfiguration> buildItems();
  public PriorityLevelConfiguration buildItem(Integer index);
  public PriorityLevelConfiguration buildFirstItem();
  public PriorityLevelConfiguration buildLastItem();
  public PriorityLevelConfiguration buildMatchingItem(Predicate<PriorityLevelConfigurationBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<PriorityLevelConfigurationBuilder> predicate);
  public A withItems(List<PriorityLevelConfiguration> items);
  public A withItems(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.PriorityLevelConfiguration... items);
  public Boolean hasItems();
  public PriorityLevelConfigurationListFluent.ItemsNested<A> addNewItem();
  public PriorityLevelConfigurationListFluent.ItemsNested<A> addNewItemLike(PriorityLevelConfiguration item);
  public PriorityLevelConfigurationListFluent.ItemsNested<A> setNewItemLike(Integer index,PriorityLevelConfiguration item);
  public PriorityLevelConfigurationListFluent.ItemsNested<A> editItem(Integer index);
  public PriorityLevelConfigurationListFluent.ItemsNested<A> editFirstItem();
  public PriorityLevelConfigurationListFluent.ItemsNested<A> editLastItem();
  public PriorityLevelConfigurationListFluent.ItemsNested<A> editMatchingItem(Predicate<PriorityLevelConfigurationBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,PriorityLevelConfigurationFluent<PriorityLevelConfigurationListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/PriorityLevelConfigurationListFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PriorityLevelConfigurationListFluent<A extends PriorityLevelConfigurationListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,PriorityLevelConfiguration item);
  public A setToItems(int index,PriorityLevelConfiguration item);
  public A addToItems(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.PriorityLevelConfiguration... items);
  public A addAllToItems(Collection<PriorityLevelConfiguration> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.PriorityLevelConfiguration... items);
  public A removeAllFromItems(Collection<PriorityLevelConfiguration> items);
  public A removeMatchingFromItems(Predicate<PriorityLevelConfigurationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PriorityLevelConfiguration> getItems();
  public List<PriorityLevelConfiguration> buildItems();
  public PriorityLevelConfiguration buildItem(int index);
  public PriorityLevelConfiguration buildFirstItem();
  public PriorityLevelConfiguration buildLastItem();
  public PriorityLevelConfiguration buildMatchingItem(Predicate<PriorityLevelConfigurationBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<PriorityLevelConfigurationBuilder> predicate);
  public A withItems(List<PriorityLevelConfiguration> items);
  public A withItems(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.PriorityLevelConfiguration... items);
  public Boolean hasItems();
  public PriorityLevelConfigurationListFluent.ItemsNested<A> addNewItem();
  public PriorityLevelConfigurationListFluent.ItemsNested<A> addNewItemLike(PriorityLevelConfiguration item);
  public PriorityLevelConfigurationListFluent.ItemsNested<A> setNewItemLike(int index,PriorityLevelConfiguration item);
  public PriorityLevelConfigurationListFluent.ItemsNested<A> editItem(int index);
  public PriorityLevelConfigurationListFluent.ItemsNested<A> editFirstItem();
  public PriorityLevelConfigurationListFluent.ItemsNested<A> editLastItem();
  public PriorityLevelConfigurationListFluent.ItemsNested<A> editMatchingItem(Predicate<PriorityLevelConfigurationBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,PriorityLevelConfigurationFluent<PriorityLevelConfigurationListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
